import zutil
import zutil.transform

# Zone: 9 SYM1
# Zone: 10 OVER
# Zone: 11 SYM2

parameters = {
    # units for dimensional quantities
    "units": "SI",
    # reference state
    "reference": "IC_1",
    #'restart' : True,
    "time marching": {
        # "unsteady": {"total time": 1.2, "time step": 0.002, "order": 2, "start": 0},
        "unsteady": {"total time": 1.2, "time step": 1.2, "order": 2, "start": 0},
        "scheme": {"name": "runge kutta", "stage": 5},
        "multigrid": 1,
        "cfl": 2.5,
        "cfl ramp factor": {"initial": 0.1, "growth": 1.05},
        "cycles": 1000,
    },
    "mesh transform matrix": zutil.transform.translate(
        [0.0, 0.0, 0.0], [0.0, 0.0, -0.5]
    ),
    "equations": "viscous",
    "viscous": {"order": "second", "precondition": True},
    "material": "air",
    "air": {
        "gamma": 1.4,
        "gas constant": 287.0,
        "Sutherlands const": 110.4,
        "Prandtl No": 0.72,
        "Turbulent Prandtl No": 0.9,
    },
    "IC_1": {
        "temperature": 277.7777,
        "pressure": 101325.0,
        "V": {"vector": [1.0, 0.0, 0.0], "Mach": 0.2},
        "Reynolds No": 150,
        "Reference Length": 1.0,
        "turbulence intensity": 1.0e-4,
        "eddy viscosity ratio": 0.1,
    },
    "BC_1": {"zone": [9, 11], "type": "symmetry"},
    "BC_2": {"zone": [10], "type": "farfield", "condition": "IC_1", "kind": "riemann"},
    "report": {
        "frequency": 5,
        "monitor": {
            "MR_1": {"name": "probe", "point": [1.07, 0.25, 0.313], "variables": ["cp"]}
        },
    },
    "write output": {
        "format": "vtk",
        "surface variables": ["V", "p", "T", "rho", "cp"],
        "volume variables": ["V", "p", "T", "rho", "m", "cp", "overset"],
        "frequency": 100,
    },
}
